pub struct AuraRow {
pub aura_id: u32,
pub uptime_ms: u64,
pub applications: u64,
pub refreshes: u64,
pub stack_seconds_x100: u64,
pub target_id: u32,
pub source_kind: i32,
pub source_id: u32,
pub affected_kind: i32,
pub affected_id: u32,
pub pull_id: Option<u32>,
pub group_id: Option<u32>,
}Fields
aura_id: u32uptime_ms: u64applications: u64refreshes: u64stack_seconds_x100: u64target_id: u32source_kind: i32source_id: u32affected_kind: i32affected_id: u32pull_id: Option<u32>group_id: Option<u32>Implementations
Sourceimpl AuraRow
impl AuraRow
Sourcepub fn source_kind(&self) -> ActorKind
pub fn source_kind(&self) -> ActorKind
Returns the enum value of source_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_source_kind(&mut self, value: ActorKind)
pub fn set_source_kind(&mut self, value: ActorKind)
Sets source_kind to the provided enum value.
Sourcepub fn affected_kind(&self) -> ActorKind
pub fn affected_kind(&self) -> ActorKind
Returns the enum value of affected_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_affected_kind(&mut self, value: ActorKind)
pub fn set_affected_kind(&mut self, value: ActorKind)
Sets affected_kind to the provided enum value.