pub struct RunningAggregateStateV1 {Show 22 fields
pub chunks_total: u32,
pub chunks_completed: u32,
pub iterations_total: u64,
pub total_fight_time_ms: u64,
pub weighted_mean_num_x10: u64,
pub m2_total_bits: u64,
pub min_dps_x10: u32,
pub max_dps_x10: u32,
pub histogram: Option<HistogramData>,
pub actions: Vec<ActionRow>,
pub auras: Vec<AuraRow>,
pub resources: Vec<ResourceRow>,
pub cooldowns: Vec<CooldownRow>,
pub execution: Option<ExecutionData>,
pub damage_profile: Option<DamageProfileData>,
pub dps_bucket_sums_x10: Vec<u64>,
pub dps_bucket_samples: Vec<u64>,
pub bucket_ms: u32,
pub representative: Option<TimelineSnapshot>,
pub representative_meta: Option<RepresentativeMeta>,
pub dictionary: Option<DictionaryView>,
pub instrumentation_coverage: Option<InstrumentationCoverage>,
}Fields
chunks_total: u32chunks_completed: u32iterations_total: u64total_fight_time_ms: u64weighted_mean_num_x10: u64m2_total_bits: u64min_dps_x10: u32max_dps_x10: u32histogram: Option<HistogramData>actions: Vec<ActionRow>auras: Vec<AuraRow>resources: Vec<ResourceRow>cooldowns: Vec<CooldownRow>execution: Option<ExecutionData>damage_profile: Option<DamageProfileData>dps_bucket_sums_x10: Vec<u64>dps_bucket_samples: Vec<u64>bucket_ms: u32representative: Option<TimelineSnapshot>representative_meta: Option<RepresentativeMeta>dictionary: Option<DictionaryView>instrumentation_coverage: Option<InstrumentationCoverage>Trait Implementations
Sourceimpl Clone for RunningAggregateStateV1
impl Clone for RunningAggregateStateV1
Sourcefn clone(&self) -> RunningAggregateStateV1
fn clone(&self) -> RunningAggregateStateV1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RunningAggregateStateV1
impl Debug for RunningAggregateStateV1
Sourceimpl Default for RunningAggregateStateV1
impl Default for RunningAggregateStateV1
Sourceimpl Message for RunningAggregateStateV1
impl Message for RunningAggregateStateV1
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RunningAggregateStateV1
impl PartialEq for RunningAggregateStateV1
impl StructuralPartialEq for RunningAggregateStateV1