pub struct TimelineMarker {
pub delta_time_ms: u32,
pub kind: i32,
pub spell_or_aura_id: u32,
pub target_id: u32,
pub amount: u32,
pub is_crit: bool,
pub source_kind: i32,
pub source_id: u32,
pub pull_id: Option<u32>,
pub group_id: Option<u32>,
pub sequence: u64,
}Fields
delta_time_ms: u32kind: i32spell_or_aura_id: u32target_id: u32amount: u32is_crit: boolsource_kind: i32source_id: u32pull_id: Option<u32>group_id: Option<u32>sequence: u64Implementations
Sourceimpl TimelineMarker
impl TimelineMarker
Sourcepub fn kind(&self) -> MarkerKind
pub fn kind(&self) -> MarkerKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: MarkerKind)
pub fn set_kind(&mut self, value: MarkerKind)
Sets kind to the provided enum value.
Sourcepub fn source_kind(&self) -> ActorKind
pub fn source_kind(&self) -> ActorKind
Returns the enum value of source_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_source_kind(&mut self, value: ActorKind)
pub fn set_source_kind(&mut self, value: ActorKind)
Sets source_kind to the provided enum value.