pub struct TimelineViewV1 {
pub duration_ms: u32,
pub bucket_ms: u32,
pub dps_per_bucket_x10: Vec<u32>,
pub dps_bucket_samples: Vec<u64>,
pub markers: Vec<TimelineMarker>,
pub aura_windows: Vec<AuraWindow>,
pub cooldown_windows: Vec<CooldownWindow>,
pub phase_markers: Vec<PhaseMarker>,
pub encounter_events: Vec<EncounterTimelineEvent>,
}Fields
duration_ms: u32bucket_ms: u32dps_per_bucket_x10: Vec<u32>dps_bucket_samples: Vec<u64>markers: Vec<TimelineMarker>aura_windows: Vec<AuraWindow>cooldown_windows: Vec<CooldownWindow>phase_markers: Vec<PhaseMarker>encounter_events: Vec<EncounterTimelineEvent>Trait Implementations
Sourceimpl Clone for TimelineViewV1
impl Clone for TimelineViewV1
Sourcefn clone(&self) -> TimelineViewV1
fn clone(&self) -> TimelineViewV1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TimelineViewV1
impl Debug for TimelineViewV1
Sourceimpl Default for TimelineViewV1
impl Default for TimelineViewV1
Sourceimpl Message for TimelineViewV1
impl Message for TimelineViewV1
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for TimelineViewV1
impl PartialEq for TimelineViewV1
impl StructuralPartialEq for TimelineViewV1